####Authoritarian Gridlock - Final Replication File (11-13-2017)####
###Rory Truex, Assistant Professor, Princeton University Department of Politics and Woodrow Wilson School of Public and International Affairs, rtruex@princeton.edu###

###LOAD PACKAGES AND FUNCTIONS###
setwd('/Users/rtruex/Google Drive/Authoritarian Gridlock/')
rm(list=ls(all=TRUE))

library(foreign)
library(Zelig)
library(ggplot2)

###LOAD DATASET###

setwd('/Users/rtruex/Google Drive/Authoritarian Gridlock/')
data<-read.csv("Authoritarian Gridlock - Data.csv",stringsAsFactors=FALSE)

#Variable Creation/Manipulation#

data$entered.date.top.t<-as.numeric(gsub(",", "", data$entered.date.top.t))
data$issued.date.t<-as.numeric(gsub(",", "", data$issued.date.t))
data$final.date.t<-as.numeric(gsub(",", "", data$final.date.t))

data$final.date.t.point<-NA
data$final.date.t.point[data$level.passed==1]<-data$final.date.t
data$final.date.t.point[data$level.passed==0]<-data$entered.date.top.t

data$delayed.10<-0
data$delayed.10[data$delayed==1 & data$years.top>10]<-1

#Subsetting#

data.top<-subset(data, data$days.top.all>-1)
data.top.passed<-subset(data.top, data.top$level.passed==1)
data.top.8t11<-subset(data.top, data.top$entered.congress.top!=7&data.top$entered.congress.top!=12)
data.top.8t11.passed<-subset(data.top.8t11, data.top.8t11$level.passed==1)

data.inc.samp<-data.top.8t11[sample(1:nrow(data.top.8t11), 75, replace=FALSE),]  
data.inc.samp.delayed<-subset(data.inc.samp, data.inc.samp$delayed==1)

#Figure: Evidence of Legislative Delay in the Chinese System#

pdf('fig2-delays.pdf', width=11, height=14)
plan_names <- c(
  `8` = "8th NPCSC Legislative Plan",
  `9` = "9th NPCSC Legislative Plan",
  `10` = "10th NPCSC Legislative Plan",
  `11` = "11th NPCSC Legislative Plan"
)
ggplot(data.inc.samp,aes(colour=factor(delayed))) + geom_segment(aes(x = entered.date.top.t, y = law.name.eng.trim, xend = final.date.t, yend = law.name.eng.trim), data = data.inc.samp) +labs(x = "NPC Entered and Passed") + labs(y = "Tier 1 Laws in NPCSC Legislative Plans") +theme_bw() +geom_point(aes(x = entered.date.top.t,y = law.name.eng.trim))  + scale_color_manual(values=alpha(c("black","red"),.5),labels=c("Not Delayed", "Delayed"),name="")  + theme(axis.ticks = element_blank(), axis.text.x = element_blank()) + geom_vline(xintercept = 1, color="grey20", lty=2) + annotate("text", x = 875, y = 1.5, label = "8th NPC") + geom_vline(xintercept = 1769, color="grey20", lty=2) + geom_vline(xintercept = 3613, color="grey20", lty=2) + geom_vline(xintercept = 5390,color="grey20", lty=2) + geom_vline(xintercept = 7215,color="grey20", lty=2) + annotate("text", x = 2700, y = 1.5, label = "9th NPC") + annotate("text", x = 4525, y = 1.5, label = "10th NPC") + annotate("text", x = 6350, y = 1.5, label = "11th NPC") + annotate("text", x = 8175, y = 1.5, label = "12th NPC")  + geom_point(data = subset(data.inc.samp,data.inc.samp$level.passed==1), aes(x = final.date.t,y = law.name.eng.trim)) + scale_x_continuous(limits = c(-51, 8600))  + facet_grid(entered.congress.top ~ .,scales="free",drop=TRUE,labeller = as_labeller(plan_names)) + annotate("text", x = 875, y = 2.5, label = "1993-",size=3) + annotate("text", x = 2700, y = 2.5, label = "1998-",size=3) + annotate("text", x = 4525, y = 2.5, label = "2003-",size=3) + annotate("text", x = 6350, y = 2.5, label = "2008-",size=3) + annotate("text", x = 8175, y = 2.5, label = "2013-",size=3) 
dev.off()

#Variation: Core Descriptive Statistics#

ftable(data$level[data$level.passed==1])

ftable(data.top.8t11$level)
summary(data.top.8t11$level.passed)
ftable(data.top.8t11$level, data.top.8t11$level.passed)

summary(data.top.8t11.passed$days.top.all)
aggregate(data.top.8t11.passed$days.top.all, list(data.top.8t11.passed$level), mean)

summary(data.top.8t11.passed$delayed.10) 
aggregate(data.top.8t11.passed$delayed.10, list(data.top.8t11.passed$level), mean) #12% figure reported in paper

summary(data.top.8t11$delayed)

#Figure: Stakeholders and Delay#

orgs.npc<-c("ARAC", "BAC", "EPRCC", "ESCPHC", "FAC", "FEAC", "IJAC")
orgs.jud<-c("SPC","SPP")
orgs.mil<-c("BLA","GLD","GSD","LSD","PAPH")
orgs.mass<-c("ACFIC","ACFTU","ACWF","CDPF","CEC")
orgs.ccp<-c("CCDI","CCGO","CLGCA","CNSC","CPCOD","CPCPD","CPLAC")
orgs.other<-c("CASS","CAST","CLS","CNPC","ICBC")
orgs.sc<-c("MCON","MII","MIT","MLSS","MOH","MOP","MOR","NFPC","PCOM","SCIO","SEPA","SFDA","AQSIQ","CBRC","CEA","CFDA","CIRC","CNTA","CSRC","HMO","MCA","MEP","MFA","MHRSS","MIIT","MLR","MOA","MOC","MOE","MOF","MOFCOM","MOHURD","MOJ","MOS","MOST","MOT","MPS","MSS","MWR","NAO","NAPSS","NASG","NBS","NDMC","NDRC","NEA","NHFPC","OLA","PBOC","SAIC","SAPPRFT","SASAC","SAT","SATCM","SAWS","SCGO","SCOPSR","SFA","SOA","SPB","SSF")

for (k in orgs.npc) {
  for (j in 1:11) {
    eval(parse(text=paste("data$org.id",k,"[grepl('",k,"', data$org",j,")==TRUE]<-1",sep="")))
  }
}

for (k in orgs.jud) {
  for (j in 1:11) {
    eval(parse(text=paste("data$org.id",k,"[grepl('",k,"', data$org",j,")==TRUE]<-1",sep="")))
  }
}

for (k in orgs.mil) {
  for (j in 1:11) {
    eval(parse(text=paste("data$org.id",k,"[grepl('",k,"', data$org",j,")==TRUE]<-1",sep="")))
  }
}

for (k in orgs.mass) {
  for (j in 1:11) {
    eval(parse(text=paste("data$org.id",k,"[grepl('",k,"', data$org",j,")==TRUE]<-1",sep="")))
  }
}

for (k in orgs.ccp) {
  for (j in 1:11) {
    eval(parse(text=paste("data$org.id",k,"[grepl('",k,"', data$org",j,")==TRUE]<-1",sep="")))
  }
}

for (k in orgs.other) {
  for (j in 1:11) {
    eval(parse(text=paste("data$org.id",k,"[grepl('",k,"', data$org",j,")==TRUE]<-1",sep="")))
  }
}

for (k in orgs.sc) {
  for (j in 1:11) {
    eval(parse(text=paste("data$org.id",k,"[grepl('",k,"', data$org",j,")==TRUE]<-1",sep="")))
  }
}

data$org.npc.tot<-rowSums(data[,c("org.idARAC", "org.idBAC", "org.idEPRCC", "org.idESCPHC","org.idFAC","org.idFEAC","org.idIJAC")], na.rm = TRUE)
data$org.ccp.tot<-rowSums(data[,c("org.idCCDI","org.idCCGO","org.idCLGCA","org.idCNSC","org.idCPCOD","org.idCPCPD","org.idCPLAC")], na.rm = TRUE)
data$org.jud.tot<-rowSums(data[,c("org.idSPC","org.idSPP")], na.rm = TRUE)
data$org.mil.tot<-rowSums(data[,c("org.idBLA","org.idGLD","org.idGSD","org.idLSD","org.idPAPH")], na.rm = TRUE)
data$org.mass.tot<-rowSums(data[,c("org.idACFIC","org.idACFTU","org.idACWF","org.idCDPF","org.idCEC")], na.rm = TRUE)
data$org.other.tot<-rowSums(data[,c("org.idCASS","org.idCAST","org.idCLS","org.idCNPC","org.idICBC")], na.rm = TRUE)
data$org.sc.tot<-rowSums(data[,c("org.idMCON","org.idMII","org.idMIT","org.idMLSS","org.idMOH","org.idMOP","org.idMOR","org.idNFPC","org.idPCOM","org.idSCIO","org.idSEPA","org.idSFDA","org.idAQSIQ","org.idCBRC","org.idCEA","org.idCFDA","org.idCIRC","org.idCNTA","org.idCSRC","org.idHMO","org.idMCA","org.idMEP","org.idMFA","org.idMHRSS","org.idMIIT","org.idMLR","org.idMOA","org.idMOC","org.idMOE","org.idMOF","org.idMOFCOM","org.idMOHURD","org.idMOJ","org.idMOS","org.idMOST","org.idMOT","org.idMPS","org.idMSS","org.idMWR","org.idNAO","org.idNAPSS","org.idNASG","org.idNBS","org.idNDMC","org.idNDRC","org.idNEA","org.idNHFPC","org.idOLA","org.idPBOC","org.idSAIC","org.idSAPPRFT","org.idSASAC","org.idSAT","org.idSATCM","org.idSAWS","org.idSCGO","org.idSCOPSR","org.idSFA","org.idSOA","org.idSPB","org.idSSF")], na.rm = TRUE)

data$org.nonnpc.tot<-data$org.ccp.tot+data$org.jud.tot+data$org.mil.tot+data$org.mass.tot+data$org.other.tot+data$org.sc.tot

data$org.nonnpc.tot.4cat<-NA
data$org.nonnpc.tot.4cat[data$org.nonnpc.tot>3]<-"4+"
data$org.nonnpc.tot.4cat[data$org.nonnpc.tot==3]<-"3"
data$org.nonnpc.tot.4cat[data$org.nonnpc.tot==2]<-"2"
data$org.nonnpc.tot.4cat[data$org.nonnpc.tot==1]<-"1"
data$org.nonnpc.tot.4cat[data$org.nonnpc.tot==0]<-"0"

data.inc<-subset(data, data$org.missing==0)
data.inc<-subset(data.inc, data.inc$days.top.all>-1)
data.inc$issue2[data.inc$issue=="political reform/rights"]<-"Political Reform/Rights"
data.inc$issue2[data.inc$issue=="economic development/regulation"]<-"Economic Development/Regulation"
data.inc$issue2[data.inc$issue=="education, culture, and society"]<-"Education, Culture and Society"
data.inc$issue2[data.inc$issue=="environmental protection"]<-"Environmental Protection"
data.inc$issue2[data.inc$issue=="foreign affairs/security"]<-"Foreign Affairs/Security"
data.inc$issue2[data.inc$issue=="health and safety"]<-"Health and Safety"
data.inc$issue2[data.inc$issue=="other"]<-"Other"
data.inc$issue2[data.inc$issue=="privatization"]<-"Privatization/Property Rights"
data.inc$issue2[data.inc$issue=="redistribution/welfare state"]<-"Economic Development/Regulation"

ftable(data.inc$org.nonnpc.tot.4cat, data.inc$delayed)
pdf('fig6a-orgs.pdf', width=7.25, height=3.5)
ggplot(data.inc, aes(x = factor(org.nonnpc.tot.4cat),y=years.top)) + geom_point(alpha=.5) + xlab("Organizational Stakeholders (orgs.tot)") + ylab("Total Years as Top Tier Law (years.top)")  + theme_bw() + coord_flip() + geom_hline(yintercept = 5,color="grey20", lty=2) + annotate("text", x = .65, y = 6.5, label = "Delayed", size=3) + annotate("text", x = .65, y = 3, label = "Not Delayed", size=3) + ggtitle("Stakeholders and Delay", subtitle = NULL) + theme(plot.title = element_text(lineheight=.8, hjust = 0.5)) + annotate("text", x = 1, y = 20, label = "0%", size=3) + annotate("text", x = 2, y = 20, label = "25%", size=3) + annotate("text", x = 3, y = 20, label = "9%", size=3) + annotate("text", x = 4, y = 20, label = "40%", size=3) + annotate("text", x = 4.25, y = 20, label = "% Delayed", size=3) 
dev.off()

ftable(data.inc$issue2, data.inc$delayed)
pdf('fig6b-issue.pdf', width=9, height=3.5)
ggplot(data.inc, aes(x = factor(issue2),y=years.top)) + geom_point(alpha=.5) + xlab("Issue Area (issue)")  + ylab("Total Years as Top Tier Law (years.top)")  + theme_bw() + coord_flip() + geom_hline(yintercept = 5,color="grey20", lty=2) + annotate("text", x = .75, y = 6.5, label = "Delayed", size=3) + annotate("text", x = .75, y = 3, label = "Not Delayed", size=3) + ggtitle("Issue Area and Delay", subtitle = NULL) + theme(plot.title = element_text(lineheight=.8, hjust = 0.5)) + annotate("text", x = 1, y = 20, label = "20%", size=3) + annotate("text", x = 2, y = 20, label = "12.5%", size=3) + annotate("text", x = 3, y = 20, label = "25%", size=3) + annotate("text", x = 4, y = 20, label = "20%", size=3) + annotate("text", x = 5, y = 20, label = "0%", size=3) + annotate("text", x = 6, y = 20, label = "33%", size=3) + annotate("text", x = 7, y = 20, label = "66%", size=3) + annotate("text", x = 8, y = 20, label = "33%", size=3) + annotate("text", x = 8.35, y = 20, label = "% Delayed", size=3) 
dev.off()

m1<-zelig(years.top~org.total, model="ls",robust=TRUE,data=data.inc) 
summary(m1)


